@@ -7,8 +7,7 @@ describe 'sahara' do
 
   let :params do
     {
-      :admin_password => 'secrete',
-      :purge_config   => false,
+      :purge_config => false,
     }
   end
 
@@ -16,7 +15,6 @@ describe 'sahara' do
     it { is_expected.to contain_class('sahara::deps') }
     it { is_expected.to contain_class('sahara::params') }
     it { is_expected.to contain_class('sahara::db') }
-    it { is_expected.to contain_class('sahara::logging') }
     it { is_expected.to contain_class('sahara::policy') }
     it { is_expected.to contain_class('mysql::bindings::python') }
     it { is_expected.to contain_exec('sahara-dbmanage') }
@@ -33,7 +31,6 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('DEFAULT/use_floating_ips').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/host').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/port').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_sahara_config('keystone_authtoken/www_authenticate_uri').with_value('http://127.0.0.1:5000/') }
       it { is_expected.to contain_sahara_config('DEFAULT/plugins').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>') }
@@ -132,32 +129,6 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
     end
 
-    context 'with zmq rpc' do
-
-      context 'with default params' do
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_bind_address').with_value('<SERVICE DEFAULT>') }
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_contexts').with_value('<SERVICE DEFAULT>') }
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_topic_backlog').with_value('<SERVICE DEFAULT>') }
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_ipc_dir').with_value('<SERVICE DEFAULT>') }
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_host').with_value('sahara') }
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_cast_timeout').with_value('<SERVICE DEFAULT>') }
-      end
-
-      context 'when passing params' do
-        before do
-          params.merge!({
-            :zeromq_bind_address => '*',
-            :zeromq_host         => 'localhost',
-            :cast_timeout        => '30',
-          })
-        end
-
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_bind_address').with_value('*') }
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_zmq_host').with_value('localhost') }
-        it { is_expected.to contain_sahara_config('DEFAULT/rpc_cast_timeout').with_value('30') }
-      end
-    end
-
     context 'with amqp rpc' do
 
       context 'with default parameters' do
@@ -230,7 +201,8 @@ describe 'sahara' do
         :use_ssl   => true,
       }
       end
-      it_raises 'a Puppet::Error', /The cert_file parameter is required when use_ssl is set to true/
+
+      it { should raise_error(Puppet::Error, /The cert_file parameter is required when use_ssl is set to true/) }
     end
 
     context 'with ssl but without key_file' do
@@ -240,7 +212,8 @@ describe 'sahara' do
         :cert_file => '/tmp/cert_file',
       }
       end
-      it_raises 'a Puppet::Error', /The key_file parameter is required when use_ssl is set to true/
+
+      it { should raise_error(Puppet::Error, /The key_file parameter is required when use_ssl is set to true/) }
     end
   end
 
